@@ -30,14 +30,16 @@
 #include "text.h"
 #include "xchatc.h"
 
-#ifndef WIN32
+#ifdef WIN32
+#include <io.h>
+#else
 #include <unistd.h>
 #define HEXCHAT_DIR "hexchat"
 #endif
 
 #define DEF_FONT "Monospace 9"
 #ifdef WIN32
-#define DEF_FONT_ALTER "Arial Unicode MS,Lucida Sans Unicode"
+#define DEF_FONT_ALTER "Arial Unicode MS,Lucida Sans Unicode,MS Gothic,Unifont"
 #endif
 
 void
@@ -314,20 +316,18 @@ get_xdir_fs (void)
 {
 	if (!xdir_fs)
 	{
-		if (portable_mode ())
-		{
-			xdir_fs = ".\\config";
-		}
-		else
-		{
 			char out[256];
 
-			if (!get_reg_str ("Software\\Microsoft\\Windows\\CurrentVersion\\"
-					"Explorer\\Shell Folders", "AppData", out, sizeof (out)))
-				return "./config";
-			xdir_fs = g_strdup_printf ("%s\\" "HexChat", out);
-		}
+			if (portable_mode () || !get_reg_str ("Software\\Microsoft\\Windows\\CurrentVersion\\Explorer\\Shell Folders", "AppData", out, sizeof (out)))
+			{
+				xdir_fs = ".\\config";
+			}
+			else
+			{
+				xdir_fs = g_strdup_printf ("%s\\" "HexChat", out);
+			}
 	}
+
 	return xdir_fs;
 }
 
@@ -357,6 +357,8 @@ static void
 check_prefs_dir (void)
 {
 	char *dir = get_xdir_fs ();
+	static char *msg = NULL;
+
 	if (access (dir, F_OK) != 0)
 	{
 #ifdef WIN32
@@ -364,7 +366,12 @@ check_prefs_dir (void)
 #else
 		if (mkdir (dir, S_IRUSR | S_IWUSR | S_IXUSR) != 0)
 #endif
-			fe_message (_("Cannot create ~/.xchat2"), FE_MSG_ERROR);
+		{
+			msg = malloc (strlen (get_xdir_fs ()) + 15);
+			sprintf (msg, "Cannot create %s", get_xdir_fs ());
+			fe_message (msg, FE_MSG_ERROR);
+			free (msg);
+		}
 	}
 }
 
@@ -384,10 +391,8 @@ default_file (void)
 /* Keep these sorted!! */
 
 const struct prefs vars[] = {
-	{"auto_save", P_OFFINT (autosave), TYPE_BOOL},
-	{"auto_save_url", P_OFFINT (autosave_url), TYPE_BOOL},
-
 	{"away_auto_unmark", P_OFFINT (auto_unmark_away), TYPE_BOOL},
+	{"away_omit_alerts", P_OFFINT (away_omit_alerts), TYPE_BOOL},
 	{"away_reason", P_OFFSET (awayreason), TYPE_STR},
 	{"away_show_message", P_OFFINT (show_away_message), TYPE_BOOL},
 	{"away_show_once", P_OFFINT (show_away_once), TYPE_BOOL},
@@ -435,6 +440,8 @@ const struct prefs vars[] = {
 	{"gui_auto_open_dialog", P_OFFINT (autodialog), TYPE_BOOL},
 	{"gui_auto_open_recv", P_OFFINT (autoopendccrecvwindow), TYPE_BOOL},
 	{"gui_auto_open_send", P_OFFINT (autoopendccsendwindow), TYPE_BOOL},
+	{"gui_chanlist_maxusers", P_OFFINT (gui_chanlist_maxusers), TYPE_INT},
+	{"gui_chanlist_minusers", P_OFFINT (gui_chanlist_minusers), TYPE_INT},
 	{"gui_dialog_height", P_OFFINT (dialog_height), TYPE_INT},
 	{"gui_dialog_left", P_OFFINT (dialog_left), TYPE_INT},
 	{"gui_dialog_top", P_OFFINT (dialog_top), TYPE_INT},
@@ -487,7 +494,7 @@ const struct prefs vars[] = {
 	{"input_balloon_time", P_OFFINT (input_balloon_time), TYPE_INT},
 	{"input_beep_chans", P_OFFINT (input_beep_chans), TYPE_BOOL},
 	{"input_beep_hilight", P_OFFINT (input_beep_hilight), TYPE_BOOL},
-	{"input_beep_msg", P_OFFINT (input_beep_priv), TYPE_BOOL},
+	{"input_beep_priv", P_OFFINT (input_beep_priv), TYPE_BOOL},
 	{"input_command_char", P_OFFSET (cmdchar), TYPE_STR},
 	{"input_filter_beep", P_OFFINT (filterbeep), TYPE_BOOL},
 	{"input_flash_chans", P_OFFINT (input_flash_chans), TYPE_BOOL},
@@ -555,9 +562,7 @@ const struct prefs vars[] = {
 
 	{"tab_chans", P_OFFINT (tabchannels), TYPE_BOOL},
 	{"tab_dialogs", P_OFFINT (privmsgtab), TYPE_BOOL},
-#ifdef WIN32
 	{"tab_icons", P_OFFINT (tab_icons), TYPE_BOOL},
-#endif
 	{"tab_layout", P_OFFINT (tab_layout), TYPE_INT},
 	{"tab_new_to_front", P_OFFINT (newtabstofront), TYPE_INT},
 	{"tab_notices", P_OFFINT (notices_tabs), TYPE_BOOL},
@@ -568,13 +573,10 @@ const struct prefs vars[] = {
 	{"tab_sort", P_OFFINT (tab_sort), TYPE_BOOL},
 	{"tab_trunc", P_OFFINT (truncchans), TYPE_INT},
 	{"tab_utils", P_OFFINT (windows_as_tabs), TYPE_BOOL},
-#ifdef WIN32
-	{"tab_xp", P_OFFINT (tab_xp), TYPE_BOOL},
-#endif
 
-	{"text_auto_copy_color", P_OFFINT (autocopy_color), TYPE_BOOL},	
-	{"text_auto_copy_stamp", P_OFFINT (autocopy_stamp), TYPE_BOOL},
-	{"text_auto_copy_text", P_OFFINT (autocopy_text), TYPE_BOOL},
+	{"text_autocopy_color", P_OFFINT (autocopy_color), TYPE_BOOL},	
+	{"text_autocopy_stamp", P_OFFINT (autocopy_stamp), TYPE_BOOL},
+	{"text_autocopy_text", P_OFFINT (autocopy_text), TYPE_BOOL},
 	{"text_background", P_OFFSET (background), TYPE_STR},
 	{"text_color_nicks", P_OFFINT (colorednicks), TYPE_BOOL},
 #ifdef WIN32
@@ -597,7 +599,9 @@ const struct prefs vars[] = {
 	{"text_show_marker", P_OFFINT (show_marker), TYPE_BOOL},
 	{"text_show_sep", P_OFFINT (show_separator), TYPE_BOOL},
 	{"text_spell_langs", P_OFFSET (spell_langs), TYPE_STR},
-	{"text_stripcolor", P_OFFINT (stripcolor), TYPE_BOOL},
+	{"text_stripcolor_msg", P_OFFINT (text_stripcolor_msg), TYPE_BOOL},
+	{"text_stripcolor_replay", P_OFFINT (text_stripcolor_replay), TYPE_BOOL},
+	{"text_stripcolor_topic", P_OFFINT (text_stripcolor_topic), TYPE_BOOL},
 	{"text_thin_sep", P_OFFINT (thin_separator), TYPE_BOOL},
 	{"text_tint_blue", P_OFFINT (tint_blue), TYPE_INT},
 	{"text_tint_green", P_OFFINT (tint_green), TYPE_INT},
@@ -607,6 +611,7 @@ const struct prefs vars[] = {
 
 	{"url_grabber", P_OFFINT (url_grabber), TYPE_BOOL},
 	{"url_grabber_limit", P_OFFINT (url_grabber_limit), TYPE_INT},
+	{"url_logging", P_OFFINT (url_logging), TYPE_BOOL},
 	{0, 0, 0},
 };
 
@@ -673,21 +678,25 @@ load_config (void)
 	prefs.fastdccsend = 1;
 #endif
 	prefs.wordwrap = 1;
-	prefs.autosave = 1;
 	prefs.autodialog = 1;
 	prefs.gui_input_spell = 1;
 	prefs.autoreconnect = 1;
 	prefs.recon_delay = 10;
 	prefs.autocopy_text = 1;
 	prefs.text_replay = 1;
+	prefs.text_stripcolor_replay = 1;
+	prefs.text_stripcolor_topic = 1;
 	prefs.tabchannels = 1;
 	prefs.tab_layout = 2;	/* 0=Tabs 1=Reserved 2=Tree */
+	prefs.tab_icons = 1;
 	prefs.tab_sort = 1;
 	prefs.paned_userlist = 1;
 	prefs.newtabstofront = 2;
 	prefs.use_server_tab = 1;
 	prefs.privmsgtab = 1;
-	/*prefs.style_inputbox = 1;*/
+	/* prefs.colorednicks = 1; */
+	prefs.style_inputbox = 1;
+	prefs.style_namelistgad = 1;
 	prefs.dccpermissions = 0600;
 	prefs.max_lines = 500;
 	prefs.mainwindow_width = 640;
@@ -717,10 +726,12 @@ load_config (void)
 	prefs.autoopendccrecvwindow = 1;
 	prefs.autoopendccsendwindow = 1;
 	prefs.autoopendccchatwindow = 1;
-	prefs.userhost = 1;
-	prefs.gui_url_mod = 4;	/* ctrl */
+	/* prevent kicks and bans caused by overwhelming who'ing after reconnects */
+	/* prefs.userhost = 1; */
+	prefs.gui_chanlist_maxusers = 9999;
+	prefs.gui_chanlist_minusers = 5;
 	prefs.gui_tray = 1;
-	prefs.gui_pane_left_size = 100;
+	prefs.gui_pane_left_size = 128;		/* with treeview icons we need a bit bigger space */
 	prefs.gui_pane_right_size = 100;
 	prefs.gui_pane_right_size_min = 80;
 	prefs.mainwindow_save = 1;
@@ -730,13 +741,14 @@ load_config (void)
 	prefs.input_tray_priv = prefs.input_tray_hilight = 1;
 	prefs.autodccsend = 2;	/* browse mode */
 	prefs.url_grabber = 1;
-	prefs.url_grabber_limit = 0; /* 0 means unlimited for backcompat */
+	prefs.url_grabber_limit = 100; /* 0 means unlimited */
 	prefs.text_search_follow = 1;
+	prefs.timestamp = 1;
 #ifdef WIN32
 	prefs.identd = 1;
 #endif
 	strcpy (prefs.spell_langs, g_getenv ("LC_ALL") ? g_getenv ("LC_ALL") : "en_US");
-	strcpy (prefs.stamp_format, "[%H:%M] ");
+	strcpy (prefs.stamp_format, "[%H:%M:%S] ");
 	strcpy (prefs.timestamp_log_format, "%b %d %H:%M:%S ");
 	strcpy (prefs.logmask, "%n-%c.log");
 	strcpy (prefs.nick_suffix, ",");
@@ -753,11 +765,14 @@ load_config (void)
 	{
 		char out[256];
 
-		if (get_reg_str ("Software\\Microsoft\\Windows\\CurrentVersion\\"
-						 "Explorer\\Shell Folders", "Personal", out, sizeof (out)))
-			snprintf (prefs.dccdir, sizeof (prefs.dccdir), "%s\\Downloads", out);
+		if (portable_mode () || !get_reg_str ("Software\\Microsoft\\Windows\\CurrentVersion\\Explorer\\Shell Folders", "Personal", out, sizeof (out)))
+		{
+			snprintf (prefs.dccdir, sizeof (prefs.dccdir), "%s\\downloads", get_xdir_utf8 ());
+		}
 		else
-			snprintf (prefs.dccdir, sizeof (prefs.dccdir), "%s\\Downloads", get_xdir_utf8 ());
+		{
+			snprintf (prefs.dccdir, sizeof (prefs.dccdir), "%s\\Downloads", out);
+		}
 	}
 #else
 	snprintf (prefs.sounddir, sizeof (prefs.sounddir), "%s/sounds", get_xdir_utf8 ());
@@ -773,7 +788,7 @@ load_config (void)
 	strcpy (prefs.font_alternative, DEF_FONT_ALTER);
 #endif
 	strcpy (prefs.dnsprogram, "host");
-	strcpy (prefs.irc_no_hilight, "NickServ,ChanServ");
+	strcpy (prefs.irc_no_hilight, "NickServ,ChanServ,InfoServ,N,Q");
 
 	g_free ((char *)username);
 	g_free ((char *)realname);
@@ -1127,7 +1142,7 @@ cmd_set (struct session *sess, char *tbuf, char *word[], char *word_eol[])
 	{
 		PrintText (sess, "No such variable.\n");
 	}
-	else if (prefs.autosave && !save_config ())
+	else if (!save_config ())
 	{
 		PrintText (sess, "Error saving changes to disk.\n");
 	}
