@@ -247,12 +247,18 @@ static const struct defaultserver def[] =
 	{0,			"irc.vendetta.com"},
 
 	{"freenode",	0,	"#hexchat"},
+#ifdef USE_OPENSSL
+	{0,				"irc.freenode.net/+6697"},
+#endif
 	{0,				"irc.freenode.net"},
 
 /*	{"Freeworld",	0},
 	{0,			"kabel.freeworld.nu"},
 	{0,			"irc.freeworld.nu"},*/
 
+	{"Fusion Latina",	0},
+	{0,					"irc.fusionlatina.org/2012"},
+
 	{"GalaxyNet",	0},
 	{0,			"irc.galaxynet.org"},
 /*	{0,			"sprynet.us.galaxynet.org"},
@@ -301,6 +307,12 @@ static const struct defaultserver def[] =
 	{0,			"Sunshine.Ca.US.Infinity-IRC.Org"},
 	{0,			"IRC.Infinity-IRC.Org"},*/
 
+	{"IRCHighWay",	0},
+#ifdef USE_OPENSSL
+	{0,				"irc.irchighway.net/+9999"},
+#endif
+	{0,				"irc.irchighway.net"},
+
 	{"IrcLink",	0},
 	{0,			"irc.irclink.net"},
 	{0,			"Alesund.no.eu.irclink.net"},
@@ -958,7 +970,7 @@ servlist_load_defaults (void)
 		if (def[i].network)
 		{
 			net = servlist_net_add (def[i].network, def[i].host, FALSE);
-			net->encoding = strdup ("IRC (Latin/Unicode Hybrid)");
+			net->encoding = strdup (IRC_DEFAULT_CHARSET);
 			if (def[i].channel)
 				net->autojoin = strdup (def[i].channel);
 			if (def[i].charset)
