@@ -351,6 +351,10 @@ session_new (server *serv, char *from, int type, int focus)
 	session *sess;
 
 	sess = malloc (sizeof (struct session));
+	if (sess == NULL)
+	{
+		return NULL;
+	}
 	memset (sess, 0, sizeof (struct session));
 
 	sess->server = serv;
@@ -591,7 +595,7 @@ static char defaultconf_commands[] =
 	"NAME DIALOG\n"		"CMD query %2\n\n"\
 	"NAME DMSG\n"			"CMD msg =%2 &3\n\n"\
 	"NAME EXIT\n"			"CMD quit\n\n"\
-	"NAME GREP\n"			"CMD lastlog -r &2\n\n"\
+	"NAME GREP\n"			"CMD lastlog -r -- &2\n\n"\
 	"NAME IGNALL\n"			"CMD ignore %2!*@* ALL\n\n"\
 	"NAME J\n"				"CMD join &2\n\n"\
 	"NAME KILL\n"			"CMD quote KILL %2 :&3\n\n"\
@@ -843,14 +847,13 @@ xchat_exit (void)
 	in_xchat_exit = TRUE;
 	plugin_kill_all ();
 	fe_cleanup ();
-	if (prefs.autosave)
+
+	save_config ();
+	if (prefs.save_pevents)
 	{
-		save_config ();
-		if (prefs.save_pevents)
-			pevent_save (NULL);
+		pevent_save (NULL);
 	}
-	if (prefs.autosave_url)
-		url_autosave ();
+
 	sound_save ();
 	notify_save ();
 	ignore_save ();
@@ -924,7 +927,7 @@ enum_windows_impl (HWND current_window, LPARAM lParam)
 	}
 
 	GetWindowText (current_window, window_name, 8);		/* name length + 1 */
-	if (stricmp (window_name, "hexchat") == 0)
+	if (strcmp (window_name, "HexChat") == 0)
 	{
 		/* use a separate if block, this way we don't have to call GetWindowModuleFileName() for each hit */
 		ZeroMemory (&module_path, sizeof (module_path));
@@ -972,7 +975,7 @@ main (int argc, char *argv[])
 	{
 		DWORD error;
 
-		mutex = CreateMutex (NULL, TRUE, "Local\hexchat");
+		mutex = CreateMutex (NULL, TRUE, "Local\\hexchat");
 		error = GetLastError ();
 
 		if (error == ERROR_ALREADY_EXISTS || mutex == NULL)
