@@ -45,6 +45,7 @@
 #include "../common/xchatc.h"
 #include "../common/plugin.h"
 #include "../common/server.h"
+#include "../common/url.h"
 #include "gtkutil.h"
 #include "maingui.h"
 #include "pixmaps.h"
@@ -57,6 +58,7 @@
 #include "fkeys.h"
 #include "plugin-tray.h"
 #include "urlgrab.h"
+#include "setup.h"
 
 #ifdef USE_XLIB
 #include <gdk/gdkx.h>
@@ -551,13 +553,31 @@ fe_set_topic (session *sess, char *topic, char *stripped_topic)
 {
 	if (!sess->gui->is_tab || sess == current_tab)
 	{
-		gtk_entry_set_text (GTK_ENTRY (sess->gui->topic_entry), stripped_topic);
+		if (prefs.text_stripcolor_topic)
+		{
+			gtk_entry_set_text (GTK_ENTRY (sess->gui->topic_entry), stripped_topic);
+		}
+		else
+		{
+			gtk_entry_set_text (GTK_ENTRY (sess->gui->topic_entry), topic);
+		}
 		mg_set_topic_tip (sess);
-	} else
+	}
+	else
 	{
 		if (sess->res->topic_text)
+		{
 			free (sess->res->topic_text);
-		sess->res->topic_text = strdup (stripped_topic);
+		}
+
+		if (prefs.text_stripcolor_topic)
+		{
+			sess->res->topic_text = strdup (stripped_topic);
+		}
+		else
+		{
+			sess->res->topic_text = strdup (topic);
+		}
 	}
 }
 
@@ -567,7 +587,7 @@ fe_set_hilight (struct session *sess)
 	if (sess->gui->is_tab)
 		fe_set_tab_color (sess, 3);	/* set tab to blue */
 
-	if (prefs.input_flash_hilight)
+	if (prefs.input_flash_hilight && !prefs.away_omit_alerts)
 		fe_flash_window (sess); /* taskbar flash */
 }
 
@@ -699,42 +719,48 @@ fe_beep (void)
 	gdk_beep ();
 }
 
-#ifndef WIN32
-static int
-lastlog_regex_cmp (char *a, regex_t *reg)
-{
-	return !regexec (reg, a, 1, NULL, REG_NOTBOL);
-}
-#endif
-
 void
-fe_lastlog (session *sess, session *lastlog_sess, char *sstr, gboolean regexp)
+fe_lastlog (session *sess, session *lastlog_sess, char *sstr, gtk_xtext_search_flags flags)
 {
-#ifndef WIN32
-	regex_t reg;
-#endif
+	GError *err = NULL;
+	xtext_buffer *buf, *lbuf;
 
-	if (gtk_xtext_is_empty (sess->res->buffer))
+	buf = sess->res->buffer;
+
+	if (gtk_xtext_is_empty (buf))
 	{
 		PrintText (lastlog_sess, _("Search buffer is empty.\n"));
 		return;
 	}
 
-	if (!regexp)
+	lbuf = lastlog_sess->res->buffer;
+	if (flags & regexp)
 	{
-		gtk_xtext_lastlog (lastlog_sess->res->buffer, sess->res->buffer,
-								 (void *) nocasestrstr, sstr);
-		return;
-	}
+		GRegexCompileFlags gcf = (flags & case_match)? 0: G_REGEX_CASELESS;
 
-#ifndef WIN32
-	if (regcomp (&reg, sstr, REG_ICASE | REG_EXTENDED | REG_NOSUB) == 0)
-	{
-		gtk_xtext_lastlog (lastlog_sess->res->buffer, sess->res->buffer,
-								 (void *) lastlog_regex_cmp, &reg);
-		regfree (&reg);
+		lbuf->search_re = g_regex_new (sstr, gcf, 0, &err);
+		if (err)
+		{
+			PrintText (lastlog_sess, _(err->message));
+			g_error_free (err);
+			return;
+		}
 	}
-#endif
+	else
+	{
+		if (flags & case_match)
+		{
+			lbuf->search_nee = g_strdup (sstr);
+		}
+		else
+		{
+			lbuf->search_nee = g_utf8_casefold (sstr, strlen (sstr));
+		}
+		lbuf->search_lnee = strlen (lbuf->search_nee);
+	}
+	lbuf->search_flags = flags;
+	lbuf->search_text = strdup (sstr);
+	gtk_xtext_lastlog (lbuf, buf);
 }
 
 void
@@ -866,7 +892,7 @@ fe_ctrl_gui (session *sess, fe_gui_action action, int arg)
 		mg_detach (sess, arg);	/* arg: 0=toggle 1=detach 2=attach */
 		break;
 	case FE_GUI_APPLY:
-		setup_apply_real (TRUE, TRUE);
+		setup_apply_real (TRUE, TRUE, TRUE);
 	}
 }
 
@@ -892,7 +918,7 @@ fe_confirm (const char *message, void (*yesproc)(void *), void (*noproc)(void *)
 	struct DCC *dcc = ud;
 
 	if (dcc->file)
-		gtkutil_file_req (message, dcc_saveas_cb, ud, dcc->file,
+		gtkutil_file_req (message, dcc_saveas_cb, ud, dcc->file, NULL,
 								FRF_WRITE|FRF_FILTERISINITIAL|FRF_NOASKOVERWRITE);
 }
 
@@ -908,13 +934,8 @@ fe_gui_info (session *sess, int info_type)
 		if (!GTK_WIDGET_VISIBLE (GTK_WIDGET (sess->gui->window)))
 #endif
 			return 2;	/* hidden (iconified or systray) */
-#if GTK_CHECK_VERSION(2,4,0)
+
 		if (gtk_window_is_active (GTK_WINDOW (sess->gui->window)))
-#else
-#if GTK_CHECK_VERSION(2,2,0)
-		if (GTK_WINDOW (sess->gui->window)->is_active)
-#endif
-#endif
 			return 1;	/* active/focused */
 
 		return 0;		/* normal (no keyboard focus or behind a window) */
@@ -1060,16 +1081,18 @@ fe_open_url_inner (const char *url)
 static void
 fe_open_url_locale (const char *url)
 {
-#ifndef WIN32
-	if (url[0] != '/' && strchr (url, ':') == NULL)
+	/* the http:// part's missing, prepend it, otherwise it won't always work */
+	if (strchr (url, ':') == NULL && url_check_word (url, strlen (url)) != WORD_PATH)
 	{
 		url = g_strdup_printf ("http://%s", url);
 		fe_open_url_inner (url);
 		g_free ((char *)url);
-		return;
 	}
-#endif
-	fe_open_url_inner (url);
+	/* we have a sane URL, send it to the browser untouched */
+	else
+	{
+		fe_open_url_inner (url);
+	}
 }
 
 void
@@ -1148,5 +1171,5 @@ fe_get_file (const char *title, char *initial,
 {
 	/* OK: Call callback once per file, then once more with file=NULL. */
 	/* CANCEL: Call callback once with file=NULL. */
-	gtkutil_file_req (title, callback, userdata, initial, flags | FRF_FILTERISINITIAL);
+	gtkutil_file_req (title, callback, userdata, initial, NULL, flags | FRF_FILTERISINITIAL);
 }
